Sidereon.GNSS.Data.Sp3ContentStartConvention (Sidereon v0.35.0)

Copy Markdown View Source

Cataloged relationship between an SP3 filename epoch and its first content epoch.

Add content_start_offset_s to the filename epoch to obtain the declared content start. The value is derived by the canonical core catalog.

Summary

Types

t()

@type t() :: %Sidereon.GNSS.Data.Sp3ContentStartConvention{
  content_start_offset_s: 0 | -86400,
  value: value()
}

value()

@type value() :: :filename_epoch | :filename_epoch_minus_one_day